@@ -2,9 +2,14 @@
 Base Request Handlers
 
 """
+from __future__ import annotations
+
 import asyncio
+import base64
+import dataclasses
 import datetime
 import logging
+import operator
 import typing
 import uuid
 from email import utils
@@ -12,6 +17,9 @@ from email import utils
 import jsonpatch
 import problemdetails
 import sprockets_postgres as postgres
+import umsgpack
+import yarl
+from ietfparse import datastructures
 from openapi_core.deserializing.exceptions import DeserializeError
 from openapi_core.schema.media_types.exceptions import InvalidContentType
 from openapi_core.templating.paths.exceptions import \
@@ -22,7 +30,7 @@ from sprockets.http import mixins
 from sprockets.mixins import mediatype
 from tornado import httputil, web
 
-from imbi import cors, errors, session, user, version
+from imbi import common, cors, errors, session, user, version
 
 LOGGER = logging.getLogger(__name__)
 
@@ -47,16 +55,15 @@ def require_permission(permission):
                 raise errors.Forbidden('%r does not have the "%s" permission',
                                        self._current_user, permission)
             return f(self, *args, **kwargs)
+
         return wrapped
+
     return _require_permission
 
 
-class RequestHandler(cors.CORSMixin,
-                     postgres.RequestHandlerMixin,
-                     mixins.ErrorLogger,
-                     problemdetails.ErrorWriter,
-                     mediatype.ContentMixin,
-                     web.RequestHandler):
+class RequestHandler(cors.CORSMixin, postgres.RequestHandlerMixin,
+                     mixins.ErrorLogger, problemdetails.ErrorWriter,
+                     mediatype.ContentMixin, web.RequestHandler):
     """Base RequestHandler class used for recipients and subscribers."""
 
     APPLICATION_JSON = 'application/json'
@@ -64,9 +71,7 @@ class RequestHandler(cors.CORSMixin,
     NAME = 'Base'
     ITEM_NAME = ''
 
-    def __init__(self,
-                 application,
-                 request: httputil.HTTPServerRequest,
+    def __init__(self, application, request: httputil.HTTPServerRequest,
                  **kwargs):
         super().__init__(application, request, **kwargs)
         self.logger = logging.getLogger(f'imbi.endpoints.{self.NAME}')
@@ -96,8 +101,7 @@ class RequestHandler(cors.CORSMixin,
         """Invoked after a request has completed"""
         super().on_finish()
         self.application.loop.add_callback(
-            self.application.stats.incr,
-            {
+            self.application.stats.incr, {
                 'key': 'http_requests',
                 'endpoint': self.NAME,
                 'method': self.request.method,
@@ -105,14 +109,12 @@ class RequestHandler(cors.CORSMixin,
             })
 
         self.application.loop.add_callback(
-            self.application.stats.add_duration,
-            {
+            self.application.stats.add_duration, {
                 'key': 'http_request_duration',
                 'endpoint': self.NAME,
                 'method': self.request.method,
                 'status': self.get_status()
-            },
-            self.request.request_time())
+            }, self.request.request_time())
 
     def compute_etag(self) -> None:
         """Override Tornado's built-in ETag generation"""
@@ -141,18 +143,14 @@ class RequestHandler(cors.CORSMixin,
         namespace.update({'version': version})
         return namespace
 
-    def on_postgres_timing(self,
-                           metric_name: str,
-                           duration: float) -> None:
+    def on_postgres_timing(self, metric_name: str, duration: float) -> None:
         """Invoked by sprockets-postgres after each query"""
         self.application.loop.add_callback(
-            self.application.stats.add_duration,
-            {
+            self.application.stats.add_duration, {
                 'key': 'postgres_query_duration',
                 'query': metric_name,
                 'endpoint': self.NAME
-            },
-            duration)
+            }, duration)
 
     def send_response(self, value: typing.Union[dict, list]) -> None:
         """Send the response to the client"""
@@ -174,7 +172,8 @@ class RequestHandler(cors.CORSMixin,
             return self.render(
                 'error.html',
                 javascript_url=self.application.settings.get('javascript_url'),
-                status_code=status_code, **kwargs)
+                status_code=status_code,
+                **kwargs)
         super().write_error(status_code, **kwargs)
 
     def _add_last_modified_header(self, value: datetime.datetime) -> None:
@@ -216,7 +215,6 @@ class RequestHandler(cors.CORSMixin,
 
 class AuthenticatedRequestHandler(RequestHandler):
     """RequestHandler base class for authenticated requests"""
-
     async def prepare(self) -> None:
         await super().prepare()
 
@@ -249,25 +247,29 @@ class ValidatingRequestHandler(AuthenticatedRequestHandler):
         try:
             self.application.validate_request(self.request)
         except DeserializeError as err:
-            raise errors.BadRequest('Failed to deserialize body: %s', err,
+            raise errors.BadRequest('Failed to deserialize body: %s',
+                                    err,
                                     detail=str(err))
         except InvalidSecurity as err:
             raise errors.InternalServerError(
-                'Invalid OpenAPI spec security: %s', err,
+                'Invalid OpenAPI spec security: %s',
+                err,
                 title='OpenAPI Security Error')
         except OperationNotFound as err:
             raise errors.MethodNotAllowed(err.method.upper())
         except InvalidContentType as err:
             raise errors.UnsupportedMediaType(err.mimetype)
         except PathNotFound as err:
-            raise errors.InternalServerError('OpenAPI Spec Error: %s', err,
+            raise errors.InternalServerError('OpenAPI Spec Error: %s',
+                                             err,
                                              title='OpenAPI Spec Error',
                                              detail=str(err))
         except ValidateError as err:
-            raise errors.BadRequest('Request failed to validate: %s', err,
-                                    detail='The request did not validate',
-                                    errors=[str(e).split('\n')[0]
-                                            for e in err.schema_errors])
+            raise errors.BadRequest(
+                'Request failed to validate: %s',
+                err,
+                detail='The request did not validate',
+                errors=[str(e).split('\n')[0] for e in err.schema_errors])
 
 
 class CRUDRequestHandler(ValidatingRequestHandler):
@@ -341,17 +343,17 @@ class CRUDRequestHandler(ValidatingRequestHandler):
         super().send_response(value)
 
     async def _delete(self, kwargs):
-        result = await self.postgres_execute(
-            self.DELETE_SQL, self._get_query_kwargs(kwargs),
-            'delete-{}'.format(self.NAME))
+        result = await self.postgres_execute(self.DELETE_SQL,
+                                             self._get_query_kwargs(kwargs),
+                                             'delete-{}'.format(self.NAME))
         if not result.row_count:
             raise errors.ItemNotFound(instance=self.request.uri)
         self.set_status(204, reason='Item Deleted')
 
     async def _get(self, kwargs):
-        result = await self.postgres_execute(
-            self.GET_SQL, self._get_query_kwargs(kwargs),
-            'get-{}'.format(self.NAME))
+        result = await self.postgres_execute(self.GET_SQL,
+                                             self._get_query_kwargs(kwargs),
+                                             'get-{}'.format(self.NAME))
         if not result.row_count or not result.row:
             raise errors.ItemNotFound(instance=self.request.uri)
         for key, value in result.row.items():
@@ -367,15 +369,17 @@ class CRUDRequestHandler(ValidatingRequestHandler):
     async def _patch(self, kwargs):
         patch_value = self.get_request_body()
 
-        result = await self.postgres_execute(
-            self.GET_SQL, self._get_query_kwargs(kwargs),
-            'get-{}'.format(self.NAME))
+        result = await self.postgres_execute(self.GET_SQL,
+                                             self._get_query_kwargs(kwargs),
+                                             'get-{}'.format(self.NAME))
         if not result.row_count:
             raise errors.ItemNotFound(instance=self.request.uri)
 
         original = dict(result.row)
-        for key in {'created_at', 'created_by',
-                    'last_modified_at', 'last_modified_by'}:
+        for key in {
+                'created_at', 'created_by', 'last_modified_at',
+                'last_modified_by'
+        }:
             if key in original:
                 del original[key]
 
@@ -388,8 +392,10 @@ class CRUDRequestHandler(ValidatingRequestHandler):
         updated = patch.apply(original)
 
         # Bail early if there are no changes
-        if not {k: original[k] for k in original
-                if k in updated and original[k] != updated[k]}:
+        if not {
+                k: original[k]
+                for k in original if k in updated and original[k] != updated[k]
+        }:
             self._add_self_link(self.request.path)
             self._add_link_header()
             return self.set_status(304)
@@ -401,9 +407,8 @@ class CRUDRequestHandler(ValidatingRequestHandler):
             updated['current_{}'.format(self.ID_KEY)] = kwargs[self.ID_KEY]
         updated['username'] = self._current_user.username
 
-        result = await self.postgres_execute(
-            self.PATCH_SQL, updated,
-            'patch-{}'.format(self.NAME))
+        result = await self.postgres_execute(self.PATCH_SQL, updated,
+                                             'patch-{}'.format(self.NAME))
         if not result.row_count:
             raise errors.DatabaseError('No rows returned from PATCH_SQL',
                                        title='Failed to update record')
@@ -428,8 +433,8 @@ class CRUDRequestHandler(ValidatingRequestHandler):
                 values[name] = self.DEFAULTS.get(name)
 
         values['username'] = self._current_user.username
-        result = await self.postgres_execute(
-            self.POST_SQL, values, 'post-{}'.format(self.NAME))
+        result = await self.postgres_execute(self.POST_SQL, values,
+                                             'post-{}'.format(self.NAME))
         if not result.row_count:
             raise errors.DatabaseError('No rows returned from POST_SQL',
                                        title='Failed to create record')
@@ -450,14 +455,14 @@ class CollectionRequestHandler(CRUDRequestHandler):
     TTL = 300
 
     async def get(self, *args, **kwargs):
-        result = await self.postgres_execute(
-            self.COLLECTION_SQL, kwargs,
-            metric_name='get-{}'.format(self.NAME))
+        result = await self.postgres_execute(self.COLLECTION_SQL,
+                                             kwargs,
+                                             metric_name='get-{}'.format(
+                                                 self.NAME))
         self.send_response(result.rows)
 
 
 class AdminCRUDRequestHandler(CRUDRequestHandler):
-
     @require_permission('admin')
     async def delete(self, *args, **kwargs):
         await super().delete(*args, **kwargs)
@@ -473,3 +478,134 @@ class AdminCRUDRequestHandler(CRUDRequestHandler):
     @require_permission('admin')
     async def post(self, *args, **kwargs):
         await super().post(*args, **kwargs)
+
+
+@dataclasses.dataclass
+class PaginationToken:
+    """Opaque token used in "next" links by the PaginatedRequestMixin"""
+
+    start: datetime.datetime
+    limit: int
+    earliest: datetime.datetime
+
+    def with_start(self, start: datetime.datetime) -> PaginationToken:
+        """Create a new token with a different start value"""
+        return PaginationToken(start=start,
+                               limit=self.limit,
+                               earliest=self.earliest)
+
+    @classmethod
+    def from_header(cls, header_val: str) -> PaginationToken:
+        """Create a token from an opaque header value"""
+        raw_token = common.urlsafe_padded_b64decode(header_val)
+        data = umsgpack.unpackb(raw_token)
+        return PaginationToken(
+            earliest=datetime.datetime.fromisoformat(data['earliest']),
+            limit=data['limit'],
+            start=(datetime.datetime.fromisoformat(data['start']) -
+                   datetime.timedelta.resolution))
+
+    def to_header(self) -> str:
+        """Generate an opaque header value from this token"""
+        return base64.urlsafe_b64encode(
+            umsgpack.packb({
+                'earliest': self.earliest.isoformat(),
+                'limit': self.limit,
+                'start': self.start.isoformat(),
+            })).decode('ascii').rstrip('=')
+
+
+QueryMethod = typing.Callable[[dict[str, typing.Any]],
+                              typing.Coroutine[None, None,
+                                               list[tuple[datetime.datetime,
+                                                          typing.Any]]]]
+"""Type signature of the function called by PaginatedRequestHandler
+
+This is something that looks like:
+
+  async def retrieve_data(
+      params: dict[str, typing.Any]) -> list[tuple[datetime.datetime, dict]]:
+    ...
+
+"""
+
+
+class PaginatedRequestMixin(web.RequestHandler):
+    """Mix this in to repeatedly retrieve query results ordered by time
+
+    Call the `fetch_items` method to call a specified query method
+    repeatedly until "token.limit" items have been retrieved.  The
+    query method is called with a well-known set of parameters and
+    returns a list of ("when", "data") tuples.  The query parameters
+    are passed as a dictionary that contains at least the following
+    keys:
+
+    * ``earlier``   the earliest (oldest) record to query for
+    * ``later``     the most recent record to query for
+    * ``remaining`` the maximum number of records to return
+
+    The query function should build a query similar that contains
+    ``... some_column BETWEEN %(earlier)s AND %(later)s ...`` as
+    well as ``... LIMIT %(remaining)s``.  The parameters dictionary
+    contains any additional parameters that are passed into the
+    ``fetch_items`` call.
+
+    Call the `pagination_token_from_request` method to retrieve the
+    pagination token from the current request if one exists.  If
+    the token does not exist, then the concrete implementation needs
+    to generate one to pass into `fetch_items`.
+
+    """
+
+    logger: logging.Logger
+
+    async def fetch_items(self, token: PaginationToken, query: QueryMethod,
+                          time_step: datetime.timedelta,
+                          **initial_params) -> list[dict]:
+        """Call this to iterate over a query function and collect the result
+
+        :param token: controls the pagination process
+        :param query: coroutine function to call to retrieve data
+        :param time_step: amount of time to "step" for each iteration.
+            This controls how much data the "query" function is asked
+            to retrieve.
+        :param initial_params: additional parameters to include when
+            calling `query`
+        :returns: list of calling `query` until `token.limit` items
+            are retrieved
+
+        """
+        buckets = []
+        params = initial_params.copy()
+        params.update({
+            'earlier': token.start - time_step,
+            'later': token.start,
+            'remaining': token.limit,
+        })
+        while params['remaining'] > 0 and params['later'] >= token.earliest:
+            buckets.extend(await query(params))
+            buckets.sort(key=operator.itemgetter(0), reverse=True)
+            params.update({
+                'earlier': params['earlier'] - time_step,
+                'later': params['earlier'],
+                'remaining': token.limit - len(buckets),
+            })
+
+        buckets = buckets[:token.limit]
+        if buckets and buckets[-1][0] > token.earliest:
+            target = yarl.URL(self.request.uri).with_query(
+                token=token.with_start(buckets[-1][0]).to_header())
+            header = datastructures.LinkHeader(str(target), [('rel', 'next')])
+            self.add_header('Link', str(header))
+
+        return [entry for _, entry in buckets]
+
+    def get_pagination_token_from_request(self) -> PaginationToken | None:
+        """Retrieve the pagination token from the request"""
+        token = self.get_query_argument('token', '')
+        if token:
+            try:
+                return PaginationToken.from_header(token)
+            except ValueError as error:
+                self.logger.warning('ignoring malformed token %r: %s', token,
+                                    error)
