@@ -6,6 +6,4 @@ from tornado import web
 
 from . import changelog
 
-URLS = [
-    web.url(r'/operations/changelog', changelog.RequestHandler)
-]
+URLS = [web.url(r'/operations/changelog', changelog.RequestHandler)]
