@@ -3,7 +3,7 @@ from imbi.endpoints import base
 
 class UserRequestHandler(base.AuthenticatedRequestHandler):
 
-    ENDPOINT = 'ui-user'
+    NAME = 'ui-user'
 
     def get(self, *args, **kwargs):
         user = self.current_user.as_dict()
